<?php
/*
 * This file is part of the PokoX package.
 * Copyright (c) 2003 - 2005 Akira Kaze
 *
 * Character set is EUC-JP.
 *
 * For license information, please view the COPYRIGHT.txt file that was 
 * distributed with this source code. If the COPYRIGHT.txt file is missing, 
 * please visit the PokoX homepage: http://www.glamenv-septzen.net/
 *
 * $Id: PlainStory.class.php,v 1.5 2005/08/11 09:01:05 fenjin Exp $
 */

/**
 * PlainStory ȡ꡼饹⥸塼
 *
 * <pre>
 * ⤻Τޤޥ롼롣åѤʤ
 * 󡦥Ȥ⤻åѤʤץWebApp
 *
 * $_POKOX[POKOX_ACI_KEY] ̤ξ硢start()"*"˥åȤ롣
 * (̤ξǤäơץ¦ȼꤷƤ硢뤤
 *  Ǥ"*"åȤƤϾ񤭤ʤ)
 * </pre>
 *
 * @author Akira Kaze <feng-jing-gsyc-2s@glamenv-septzen.net>
 * @package PokoX
 * @since 1.0
 */
class PlainStory extends PokoXStory
{

	function start(&$pokox)
	{
		global $_POKOX;
		$_POKOX = array();
		if(!isset($_POKOX["pokox_aci"]))
			$_POKOX["pokox_aci"] = "*";
	}
	
	function story(&$pokox)
	{
		if(isset($_GET[POKOX_STORY_KEY])) {
			$story = $_GET[POKOX_STORY_KEY];
		} else if(isset($_POST[POKOX_STORY_KEY])) {
			$story = $_POST[POKOX_STORY_KEY];
		} else {
			$story = "";
		}

		return $story;
	}
	
	function end(&$pokox)
	{
	}
}
	
?>